@@ -26,13 +26,13 @@ import (
 	"k8s.io/apimachinery/pkg/api/equality"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/runtime/schema"
+	net "knative.dev/networking/pkg/apis/networking"
 	"knative.dev/pkg/apis"
 	"knative.dev/pkg/apis/duck"
 	duckv1 "knative.dev/pkg/apis/duck/v1"
 	apistest "knative.dev/pkg/apis/testing"
 	"knative.dev/pkg/ptr"
 	av1alpha1 "knative.dev/serving/pkg/apis/autoscaling/v1alpha1"
-	net "knative.dev/serving/pkg/apis/networking"
 	"knative.dev/serving/pkg/apis/serving"
 	v1 "knative.dev/serving/pkg/apis/serving/v1"
 )
@@ -56,6 +56,14 @@ func TestRevisionDuckTypes(t *testing.T) {
 	}
 }
 
+func TestRevisionGetConditionSet(t *testing.T) {
+	r := &Revision{}
+
+	if got, want := r.GetConditionSet().GetTopLevelConditionType(), apis.ConditionReady; got != want {
+		t.Errorf("GetTopLevelCondition- Actual:%v, expected:%v", got, want)
+	}
+}
+
 func TestIsActivationRequired(t *testing.T) {
 	cases := []struct {
 		name                 string
@@ -403,67 +411,6 @@ func TestRevisionGetGroupVersionKind(t *testing.T) {
 	}
 }
 
-func TestRevisionBuildRefFromName(t *testing.T) {
-	r := &Revision{
-		ObjectMeta: metav1.ObjectMeta{
-			Namespace: "foo-space",
-			Name:      "foo",
-		},
-		Spec: RevisionSpec{
-			DeprecatedBuildName: "bar-build",
-		},
-	}
-	got := *r.DeprecatedBuildRef()
-	want := corev1.ObjectReference{
-		APIVersion: "build.knative.dev/v1alpha1",
-		Kind:       "Build",
-		Namespace:  "foo-space",
-		Name:       "bar-build",
-	}
-	if got != want {
-		t.Errorf("got: %#v, want: %#v", got, want)
-	}
-}
-
-func TestRevisionBuildRef(t *testing.T) {
-	buildRef := corev1.ObjectReference{
-		APIVersion: "testing.build.knative.dev/v1alpha1",
-		Kind:       "Build",
-		Namespace:  "foo-space",
-		Name:       "foo-build",
-	}
-	r := &Revision{
-		ObjectMeta: metav1.ObjectMeta{
-			Namespace: "foo-space",
-			Name:      "foo",
-		},
-		Spec: RevisionSpec{
-			DeprecatedBuildName: "bar",
-			DeprecatedBuildRef:  &buildRef,
-		},
-	}
-	got := *r.DeprecatedBuildRef()
-	want := buildRef
-	if got != want {
-		t.Errorf("got: %#v, want: %#v", got, want)
-	}
-}
-
-func TestRevisionBuildRefNil(t *testing.T) {
-	r := &Revision{
-		ObjectMeta: metav1.ObjectMeta{
-			Namespace: "foo-space",
-			Name:      "foo",
-		},
-	}
-	got := r.DeprecatedBuildRef()
-
-	var want *corev1.ObjectReference
-	if got != want {
-		t.Errorf("got: %#v, want: %#v", got, want)
-	}
-}
-
 func TestRevisionGetProtocol(t *testing.T) {
 	containerWithPortName := func(name string) corev1.Container {
 		return corev1.Container{Ports: []corev1.ContainerPort{{Name: name}}}
@@ -590,38 +537,6 @@ func TestRevisionGetLastPinned(t *testing.T) {
 	}
 }
 
-func TestRevisionIsReachable(t *testing.T) {
-	tests := []struct {
-		name   string
-		labels map[string]string
-		want   bool
-	}{{
-		name:   "has route annotation",
-		labels: map[string]string{serving.RouteLabelKey: "the-route"},
-		want:   true,
-	}, {
-		name:   "empty route annotation",
-		labels: map[string]string{serving.RouteLabelKey: ""},
-		want:   false,
-	}, {
-		name:   "no route annotation",
-		labels: nil,
-		want:   false,
-	}}
-
-	for _, tt := range tests {
-		t.Run(tt.name, func(t *testing.T) {
-			rev := Revision{ObjectMeta: metav1.ObjectMeta{Labels: tt.labels}}
-
-			got := rev.IsReachable()
-
-			if got != tt.want {
-				t.Errorf("got: %t, want: %t", got, tt.want)
-			}
-		})
-	}
-}
-
 func TestPropagateDeploymentStatus(t *testing.T) {
 	rev := &RevisionStatus{}
 	rev.InitializeConditions()
@@ -820,7 +735,48 @@ func TestGetContainer(t *testing.T) {
 			Image: "foo",
 		},
 	}, {
-		name: "get first container info even after passing multiple",
+		name: "get container info",
+		status: RevisionSpec{
+			RevisionSpec: v1.RevisionSpec{
+				PodSpec: corev1.PodSpec{
+					Containers: []corev1.Container{{
+						Name:  "servingContainer",
+						Image: "firstImage",
+					}},
+				},
+			},
+		},
+		want: &corev1.Container{
+			Name:  "servingContainer",
+			Image: "firstImage",
+		},
+	}, {
+		name: "get serving container info even if there are multiple containers",
+		status: RevisionSpec{
+			RevisionSpec: v1.RevisionSpec{
+				PodSpec: corev1.PodSpec{
+					Containers: []corev1.Container{{
+						Name:  "firstContainer",
+						Image: "firstImage",
+						Ports: []corev1.ContainerPort{{
+							ContainerPort: 8888,
+						}},
+					}, {
+						Name:  "secondContainer",
+						Image: "secondImage",
+					}},
+				},
+			},
+		},
+		want: &corev1.Container{
+			Name:  "firstContainer",
+			Image: "firstImage",
+			Ports: []corev1.ContainerPort{{
+				ContainerPort: 8888,
+			}},
+		},
+	}, {
+		name: "get empty container when passed multiple containers without the container port",
 		status: RevisionSpec{
 			RevisionSpec: v1.RevisionSpec{
 				PodSpec: corev1.PodSpec{
@@ -834,10 +790,7 @@ func TestGetContainer(t *testing.T) {
 				},
 			},
 		},
-		want: &corev1.Container{
-			Name:  "firstContainer",
-			Image: "firstImage",
-		},
+		want: &corev1.Container{},
 	}}
 	for _, tc := range cases {
 		t.Run(tc.name, func(t *testing.T) {
